@@ -37,20 +37,35 @@ of unsigned characters of the appropriate length
 =cut
 
 use strict;
-use vars qw(@ISA %fields);
+use vars qw(@ISA %fields @field_info);
 
 require Font::TTF::Table;
 use Font::TTF::Utils;
 
 @ISA = qw(Font::TTF::Table);
+@field_info = (
+    'version' => 'f',
+    'FontNumber' => 'L',
+    'Pitch' => 'S',
+    'xHeight' => 'S',
+    'Style' => 'S',
+    'TypeFamily' => 'S',
+    'CapHeight' => 'S',
+    'SymbolSet' => 'S',
+    'Typeface' => 'C16',
+    'CharacterComplement' => 'C8',
+    'FileName' => 'C6',
+    'StrokeWeight' => 'C',
+    'WidthType' => 'C',
+    'SerifStyle' => 'c');
 
 sub init
 {
-    my ($k, $v, $c);
-    while (<Font::TTF::Pclt::DATA>)
+    my ($k, $v, $c, $i);
+    for ($i = 0; $i < $#field_info; $i += 2)
     {
-        ($k, $v, $c) = TTF_Init_Fields($_, $c);
-        next unless $k ne "";
+        ($k, $v, $c) = TTF_Init_Fields($field_info[$i], $c, $field_info[$i + 1]);
+        next unless defined $k && $k ne "";
         $fields{$k} = $v;
     }
 }
@@ -99,25 +114,8 @@ None known
 
 =head1 AUTHOR
 
-Martin Hosken L<Martin_Hosken@sil.org>. See L<Font::TTF::Font> for copyright and
+Martin Hosken Martin_Hosken@sil.org. See L<Font::TTF::Font> for copyright and
 licensing.
 
 =cut
 
-
-__DATA__
-version, f
-FontNumber, L
-Pitch, S
-xHeight, S
-Style, S
-TypeFamily, S
-CapHeight, S
-SymbolSet, S
-Typeface, C16
-CharacterComplement, C8
-FileName, C6
-StrokeWeight, C
-WidthType, C
-SerifStyle, c
-
