@@ -1,7 +1,7 @@
 package Font::TTF::PSNames;
 
 use strict;
-use vars qw(%names);
+use vars qw(%names %doubles);
 
 %names = (
     '0020' => 'space',
@@ -99,7 +99,7 @@ use vars qw(%names);
     '007C' => 'bar',
     '007D' => 'braceright',
     '007E' => 'asciitilde',
-    '00A0' => 'space',
+#    '00A0' => 'space',
     '00A1' => 'exclamdown',
     '00A2' => 'cent',
     '00A3' => 'sterling',
@@ -112,7 +112,7 @@ use vars qw(%names);
     '00AA' => 'ordfeminine',
     '00AB' => 'guillemotleft',
     '00AC' => 'logicalnot',
-    '00AD' => 'hyphen',
+#    '00AD' => 'hyphen',
     '00AE' => 'registered',
     '00AF' => 'macron',
     '00B0' => 'degree',
@@ -338,13 +338,13 @@ use vars qw(%names);
     '01FF' => 'oslashacute',
     '0218' => 'Scommaaccent',
     '0219' => 'scommaaccent',
-    '021A' => 'Tcommaaccent',
-    '021B' => 'tcommaaccent',
+#    '021A' => 'Tcommaaccent',
+#    '021B' => 'tcommaaccent',
     '02BC' => 'afii57929',
     '02BD' => 'afii64937',
     '02C6' => 'circumflex',
     '02C7' => 'caron',
-    '02C9' => 'macron',
+#    '02C9' => 'macron',
     '02D8' => 'breve',
     '02D9' => 'dotaccent',
     '02DA' => 'ring',
@@ -370,7 +370,7 @@ use vars qw(%names);
     '0391' => 'Alpha',
     '0392' => 'Beta',
     '0393' => 'Gamma',
-    '0394' => 'Delta',
+#    '0394' => 'Delta',
     '0395' => 'Epsilon',
     '0396' => 'Zeta',
     '0397' => 'Eta',
@@ -390,7 +390,7 @@ use vars qw(%names);
     '03A6' => 'Phi',
     '03A7' => 'Chi',
     '03A8' => 'Psi',
-    '03A9' => 'Omega',
+#    '03A9' => 'Omega',
     '03AA' => 'Iotadieresis',
     '03AB' => 'Upsilondieresis',
     '03AC' => 'alphatonos',
@@ -409,7 +409,7 @@ use vars qw(%names);
     '03B9' => 'iota',
     '03BA' => 'kappa',
     '03BB' => 'lambda',
-    '03BC' => 'mu',
+#    '03BC' => 'mu',
     '03BD' => 'nu',
     '03BE' => 'xi',
     '03BF' => 'omicron',
@@ -693,28 +693,28 @@ use vars qw(%names);
     '203A' => 'guilsinglright',
     '203C' => 'exclamdbl',
     '2044' => 'fraction',
-    '2070' => 'zerosuperior',
-    '2074' => 'foursuperior',
-    '2075' => 'fivesuperior',
-    '2076' => 'sixsuperior',
-    '2077' => 'sevensuperior',
-    '2078' => 'eightsuperior',
-    '2079' => 'ninesuperior',
-    '207D' => 'parenleftsuperior',
-    '207E' => 'parenrightsuperior',
-    '207F' => 'nsuperior',
-    '2080' => 'zeroinferior',
-    '2081' => 'oneinferior',
-    '2082' => 'twoinferior',
-    '2083' => 'threeinferior',
-    '2084' => 'fourinferior',
-    '2085' => 'fiveinferior',
-    '2086' => 'sixinferior',
-    '2087' => 'seveninferior',
-    '2088' => 'eightinferior',
-    '2089' => 'nineinferior',
-    '208D' => 'parenleftinferior',
-    '208E' => 'parenrightinferior',
+#    '2070' => 'zerosuperior',
+#    '2074' => 'foursuperior',
+#    '2075' => 'fivesuperior',
+#    '2076' => 'sixsuperior',
+#    '2077' => 'sevensuperior',
+#    '2078' => 'eightsuperior',
+#    '2079' => 'ninesuperior',
+#    '207D' => 'parenleftsuperior',
+#    '207E' => 'parenrightsuperior',
+#    '207F' => 'nsuperior',
+#    '2080' => 'zeroinferior',
+#    '2081' => 'oneinferior',
+#    '2082' => 'twoinferior',
+#    '2083' => 'threeinferior',
+#    '2084' => 'fourinferior',
+#    '2085' => 'fiveinferior',
+#    '2086' => 'sixinferior',
+#    '2087' => 'seveninferior',
+#    '2088' => 'eightinferior',
+#    '2089' => 'nineinferior',
+#    '208D' => 'parenleftinferior',
+#    '208E' => 'parenrightinferior',
     '20A1' => 'colonmonetary',
     '20A3' => 'franc',
     '20A4' => 'lira',
@@ -764,9 +764,9 @@ use vars qw(%names);
     '220F' => 'product',
     '2211' => 'summation',
     '2212' => 'minus',
-    '2215' => 'fraction',
+#    '2215' => 'fraction',
     '2217' => 'asteriskmath',
-    '2219' => 'periodcentered',
+#    '2219' => 'periodcentered',
     '221A' => 'radical',
     '221D' => 'proportional',
     '221E' => 'infinity',
@@ -886,14 +886,25 @@ use vars qw(%names);
     'FB4B' => 'afii57700',
 );
 
+# %doubles = (map{$_ => "uni$_"} qw(0394 03A9 0162 2215 00AD 02C9 03BC 2219 00A0 0163));
+
 sub lookup
 {
-    my ($num) = @_;
+    my ($num, $noalt) = @_;
     my ($val) = sprintf("%04X", $num);
 
-    return $names{$val} if (defined $names{$val});
-    return "u$val" unless ($num == 0);
-    return '.notdef';
+    if (defined $names{$val})
+    {
+        return $names{$val};
+#        return $names{$val} if ($noalt);
+#        return $doubles{$val} || $names{$val};
+    }
+    elsif ($num > 0xFFFF)
+    { return "u$val"; }
+    elsif ($num)
+    { return "uni$val"; }
+    else
+    { return ".notdef"; }
 }
 
 1;
